<?php

add_action( 'cmb2_admin_init', 'dentalia_metaboxes' );
/**
 * Define the metabox and field configurations.
 */

function dentalia_metaboxes() {
    global $orion_options; 
    // Start with an underscore to hide fields from custom fields list
    $prefix = '_dentalia_';

/* Post formats */
    $quote = new_cmb2_box( array(
        'id'            => 'dentalia_post_format_quote',
        'title'         => esc_html__( 'Quote Post Format', 'dentalia' ),
        'object_types'  => array( 'post', ), // Post type
        'context'       => 'normal',
        'priority'      => 'high',
        'show_names'    => true, // Show field names on the left
    ) );


    $status = new_cmb2_box( array(
        'id'            => 'dentalia_post_format_status',
        'title'         => esc_html__( 'Status Post Format', 'dentalia' ),
        'object_types'  => array( 'post', ), // Post type
        'context'       => 'normal',
        'priority'      => 'high',
        'show_names'    => true, // Show field names on the left
    ) );
    // Status text field
    $status->add_field( array(
          'name' => esc_html__('Status', 'dentalia'),
          'desc' => '',
          'id'   => $prefix.'status',
          'type' => 'textarea_small',
        )
    );

    // Quote text field
    $quote->add_field( array(
          'name' => esc_html__('Quote', 'dentalia'),
          'desc' => '',
          'id'   => $prefix.'quote',
          'type' => 'textarea_small',
        )
    );
    $quote->add_field( array(
          'name' => esc_html__('Source Name', 'dentalia'),
          'desc' => '',
          'id'   => $prefix.'quote_source_name',
          'type' => 'text',
        )
    );

    $video = new_cmb2_box( array(
        'id'            => 'dentalia_post_format_video',
        'title'         => esc_html__( 'Video Post Format', 'dentalia' ),
        'object_types'  => array( 'post', ), // Post type
        'context'       => 'normal',
        'priority'      => 'high',
        'show_names'    => true, // Show field names on the left
    ) );

    $video->add_field( array(
        'name' => esc_html__( 'oEmbed', 'dentalia' ),
        'desc' => __( 'Enter a youtube, Vimeo, or TED URL. Supports services listed at <a href="http://codex.wordpress.org/Embeds">http://codex.wordpress.org/Embeds</a>.', 'dentalia' ),
        'id'   => $prefix . 'video_embed',
        'type' => 'oembed',
        )
    );

    $link = new_cmb2_box( array(
        'id'            => 'dentalia_post_format_link',
        'title'         => esc_html__( 'Link Post Format', 'dentalia' ),
        'object_types'  => array( 'post', ), // Post type
        'context'       => 'normal',
        'priority'      => 'high',
        'show_names'    => true, // Show field names on the left
    ) );
    $link->add_field( array(
        'name' => __( 'link title', 'dentalia' ),
        'desc' => __( 'Text displayed', 'dentalia' ),
        'id'   => $prefix . 'link_title',
        'type' => 'text',
        )
    ); 
    $link->add_field( array(
        'name' => __( 'URL', 'dentalia' ),
        'desc' => __( 'Paste a link', 'dentalia' ),
        'id'   => $prefix . 'url',
        'type' => 'text_url',
        )
    );
    $link->add_field( array(
          'name' => esc_html__('Link description', 'dentalia'),
          'desc' => '',
          'id'   => $prefix.'link_desc',
          'type' => 'textarea_small',
        )
    );    
    $audio = new_cmb2_box( array(
        'id'            => 'dentalia_post_format_audio',
        'title'         => esc_html__( 'Audio Post Format', 'dentalia' ),
        'object_types'  => array( 'post', ), // Post type
        'context'       => 'normal',
        'priority'      => 'high',
        'show_names'    => true, // Show field names on the left
    ) );

    $audio->add_field( array(
        'name' => esc_html__( 'oEmbed', 'dentalia' ),
        'desc' => __( 'Enter a SoundCloud, Spotify, or similar URL. Supports services listed at <a href="http://codex.wordpress.org/Embeds">http://codex.wordpress.org/Embeds</a>.', 'dentalia' ),
        'id'   => $prefix . 'audio_embed',
        'type' => 'oembed',
        )
    );   
    $audio->add_field( array(
        'name'         => __( 'Multiple Files', 'dentalia' ),
        'desc'         => __( 'Upload or add multiple audio files. Accepts mp3, ogg, and wav formats', 'dentalia' ),
        'id'           => $prefix . 'audio_file',
        'type'         => 'file_list',
        'preview_size' => array( 100, 100 ), // Default: array( 50, 50 )
    ) );    

/* Page heading */
    $post_heading = new_cmb2_box( array(
        'id'            => 'post_heading',
        'title'         => esc_html__( 'Page Heading Settings', 'dentalia' ),
        'object_types'  => array( 'post', 'page', 'team-member' ), // Post type
        'context'       => 'normal',
        'priority'      => 'high',
        'show_names'    => true, // Show field names on the left
    ) );

    $post_heading->add_field( array(
        'name' => esc_html__( 'Hide Page Heading?', 'dentalia' ),
        'id'   => $prefix .'hide_heading',
        'type' => 'checkbox',
    ) );


    $default_heading = orion_get_option('post_heading_type', false);
    $post_heading->add_field( array(
        'name'             => 'Choose heading',
        'id'   => $prefix .'heading_type',
        'type'             => 'select',
        'show_option_none' => false,
        'default'          => $default_heading,
        'options'          => array(
            'classic'    => __( 'Classic', 'dentalia' ),
            'centered'   => __( 'Centered', 'dentalia' ),
            'left' => __( 'Left', 'dentalia' ),    
        )
    ) ); 

    $post_heading->add_field( array(
        'name'             => 'Text color',
        'id'   => $prefix .'heading_text_color',
        'type'             => 'select',
        'show_option_none' => false,
        'default'          => 'text-default',
        'options'          => array(
            'text-default'    => __( 'Default color', 'dentalia' ),
            'text-light'   => __( 'Light color', 'dentalia' ),
            'text-dark' => __( 'Dark color', 'dentalia' ),    
        )
    ) );

    $post_heading->add_field( array(
        'name'    => 'Change background image',
        'id'      => $prefix . 'heading_bg_image',
        'type'    => 'file',
        'options' => array(
            'url' => false, // Hide the text input for the url
        ),
        'text'    => array(
            'add_upload_file_text' => 'Add image' // Change upload button text. Default: "Add or Upload File"
        ),
    ) );

    $post_heading->add_field( array(
        'name'             => 'Overlay',
        'id'   => $prefix .'orion_overlay',
        'type'             => 'select',
        'show_option_none' => false,
        'default'          => 'default',
        'options'          => array(
            'default' => __( 'None', 'dentalia' ),
            'overlay-dark' => __( 'Dark Overlay', 'dentalia' ),
            'overlay-light' => __( 'Light Overlay', 'dentalia' ),
            'overlay-c1' => __( 'Main theme color', 'dentalia' ),
            'overlay-c2' => __( 'Secondary theme color', 'dentalia' ),
            'overlay-c3' => __( 'Tertiary theme color', 'dentalia' ),
            'overlay-c2-c1' => __( 'Gradient 1', 'dentalia' ),                  
            'overlay-c1-c2' => __( 'Gradient 2', 'dentalia' ),   
        )
    ) );

    $post_heading->add_field( array(
        'name'             => 'Background image behaviour',
        'id'   => $prefix .'orion_parallax',
        'type'             => 'select',
        'show_option_none' => false,
        'default'          => 'default',
        'options'          => array(
            'default' => __( 'Default', 'dentalia' ),
            'bg-fixed' => __( 'Fixed', 'dentalia' ),
            'vertical_up' => __( 'Parallax Top to bottom', 'dentalia' ),
            'vertical_down' => __( 'Parallax Bottom to top', 'dentalia' ),
            'horizontal_left' => __( 'Parallax Right to left', 'dentalia' ),
            'horizontal_right' => __( 'Parallax Left to right', 'dentalia' ),
        )
    ) ); 

    $post_heading->add_field( array(
        'name'    => 'Top Padding',
        'desc'    => __( 'Value in px', 'dentalia' ),
        'default' => '',
        'id'      => $prefix .'top_padding',
        'type'    => 'text_small',
    ) );

    $post_heading->add_field( array(
        'name'    => 'Bottom Padding',
        'desc'    => __( 'Value in px', 'dentalia' ),
        'default' => '',
        'id'      => $prefix .'bottom_padding',
        'type'    => 'text_small',
    ) );
     
/* END Page heading */

/* post paddings */

    $post_paddings = new_cmb2_box( array(
        'id'            => 'post_paddings',
        'title'         => esc_html__( 'Page Spacing', 'dentalia' ),
        'object_types'  => array( 'post', 'page', 'team-member' ), // Post type
        'context'       => 'normal',
        'priority'      => 'high',
        'show_names'    => true, // Show field names on the left
    ) );

    $post_paddings->add_field( array(
        'name' => esc_html__( 'Remove Top Spacing?', 'dentalia' ),
        'id'   => $prefix .'remove_padding_top',
        'type' => 'checkbox',
    ) );

    $post_paddings->add_field( array(
        'name' => esc_html__( 'Remove Bottom Spacing?', 'dentalia' ),
        'id'   => $prefix .'remove_padding_bottom',
        'type' => 'checkbox',
    ) );     

/*sidebars*/

/* Sidebars (posts) */
    $post_sidebars = new_cmb2_box( array(
        'id'            => 'post_sidebars',
        'title'         => esc_html__( 'Choose sidebars', 'dentalia' ),
        'object_types'  => array( 'post', 'team-member'), // Post type
        'context'       => 'normal',
        'priority'      => 'high',
        'show_names'    => true, // Show field names on the left
    ) );

/*get sidebars from wp_registered_sidebars*/
    $sidebar_options = array();
    $empty = "no_sidebar";
    $sidebar_options[$empty] = "-- None --";
    
    $allsidebars = $GLOBALS['wp_registered_sidebars'];

    foreach ($allsidebars as $key => $sidebar) {
        $s_name = $sidebar['name'];
        $s_slug = $sidebar['id'];
        $sidebar_options[$s_slug] = $s_name;
    }      

/*check if there are any defaults in theme options */
    if (isset($orion_options['post-sidebar-left-defauts']) && ($orion_options['post-sidebar-left-defauts'] != "")) {
        $default_left = $orion_options['post-sidebar-left-defauts'];
    } else {
        $default_left = array('no_sidebar');
    }

    if (isset($orion_options['post-sidebar-right-defauts']) && ($orion_options['post-sidebar-right-defauts'] != "")) {
        $default_right = $orion_options['post-sidebar-right-defauts'];
    } else {
        $default_right = array('no_sidebar');
    }
/* add sidebar metaboxes (posts) */
    $post_sidebars->add_field( array(
        'name'             => __( 'Left sidebar', 'dentalia' ),
        'id'               => $prefix . 'post_sidebar_select_left',
        'type'             => 'select',
        'show_option_none' => false,
        'default'          => $default_left,
        'options'          => $sidebar_options 
    ) );

    $post_sidebars->add_field( array(
        'name'             => __( 'Right sidebar', 'dentalia' ),
        'id'               => $prefix . 'post_sidebar_select_right',
        'type'             => 'select',
        'show_option_none' => false,
        'default'          => $default_right,
        'options'          => $sidebar_options 

    ) );    

/* Sidebars (pages) */
    $page_sidebars = new_cmb2_box( array(
        'id'            => 'pages_sidebars',
        'title'         => esc_html__( 'Sidebars and widget areas', 'dentalia' ),
        'object_types'  => array( 'page', ), // Post type
        'context'       => 'normal',
        'priority'      => 'high',
        'show_names'    => true, // Show field names on the left
    ) );

    if (isset($orion_options['page-sidebar-left-defauts']) && ($orion_options['page-sidebar-left-defauts'] != "")) {
        $page_default_left = $orion_options['page-sidebar-left-defauts'];
    } else {
        $page_default_left = array('no_sidebar');
    }

    if (isset($orion_options['page-sidebar-right-defauts']) && ($orion_options['page-sidebar-right-defauts'] != "")) {
        $page_default_right = $orion_options['page-sidebar-right-defauts'];
    } else {
        $page_default_right = array('no_sidebar');
    }

    $page_sidebars->add_field( array(
        'name'             => __( 'Left sidebar', 'dentalia' ),
        'id'               => $prefix . 'page_sidebar_select_left',
        'type'             => 'select',
        'show_option_none' => false,
        'default'          => $page_default_left,
        'options'          => $sidebar_options 
    ) );

    $page_sidebars->add_field( array(
        'name'             => __( 'Right sidebar', 'dentalia' ),
        'id'               => $prefix . 'page_sidebar_select_right',
        'type'             => 'select',
        'show_option_none' => false,
        'default'          => $page_default_right,
        'options'          => $sidebar_options 

    ) ); 
    $page_sidebars->add_field( array(
        'name' => esc_html__( 'Hide Prefooter widget area (if active)?', 'dentalia' ),
        'id'   => $prefix .'hide_prefooter',
        'default' => false,
        'type' => 'checkbox',
    ) );      

/* team-members */
    //contacts
    $team_info = new_cmb2_box( array(
        'id'            => 'team_members_info',
        'title'         => __( 'About', 'dentalia' ),
        'object_types'  => array( 'team-member', ), // Post type
        'context'       => 'normal',
        'priority'      => 'high',
        'show_names'    => true, // Show field names on the left
    ));
    $team_info->add_field( array(
        'name'    => __( 'Medical title', 'dentalia' ),
        'id'      => 'medical_title',
        'type'    => 'text',
    ));        
    $team_info -> add_field( array(
        'name'    => __( 'Intro text', 'dentalia' ),
        'id'      => 'short_about',
        'type'    => 'wysiwyg',
        'options' => array(),
    ) );

    $team_contact = new_cmb2_box( array(
        'id'            => 'team_members_contact_metabox',
        'title'         => __( 'Social info', 'dentalia' ),
        'object_types'  => array( 'team-member', ), // Post type
        'context'       => 'normal',
        'priority'      => 'high',
        'show_names'    => true, // Show field names on the left
    ));

    $team_contact -> add_field( array(
        'id'          => 'member_social_icons',
        'type'        => 'group',
        'description' => __( 'Add social links', 'dentalia' ),
        'repeatable'  => true, // use false if you want non-repeatable group
        'options'     => array(
            'group_title'   => __( 'Entry {#}', 'dentalia' ), // since version 1.1.4, {#} gets replaced by row number
            'add_button'    => __( 'Add Another Entry', 'dentalia' ),
            'remove_button' => __( 'Remove Entry', 'dentalia' ),
            'sortable'      => true, // beta
            'closed'     => true, // true to have the groups closed by default
        ),
    ) );

    $team_contact->add_group_field( 'member_social_icons', array(
        'name'             => 'Add social icons',
        'id'               => 'social_icons',
        'type'             => 'select',
        'show_option_none' => false,
        'default'          => '',
        'options'          => array(
            'fa fa-linkedin'    => __( 'LinkedIn', 'dentalia' ),
            'fa-google-plus'   => __( 'Google +', 'dentalia' ),
            'fa-facebook' => __( 'Facebook', 'dentalia' ),
            'fa-twitter'    => __( 'Twitter', 'dentalia' ),
            'fa-youtube'   => __( 'Youtube', 'dentalia' ),
            'fa-snapchat' => __( 'SnapChat', 'dentalia' ),      
            'fa-envelope-o' => __( 'Email', 'dentalia' ),      
        )
    ) );

    $team_contact->add_group_field( 'member_social_icons', array(
    'name' => __( 'Link to social profile', 'dentalia' ),
    'id'   => 'social_links',
    'type' => 'text_url',
    // 'protocols' => array( 'http', 'https', 'ftp', 'ftps', 'mailto', 'news', 'irc', 'gopher', 'nntp', 'feed', 'telnet' ), // Array of allowed protocols
    ) );
}
