<?php // Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit; 

/* define root path */
define('ORION_ROOT', get_template_directory_uri());

/*
* Theme setup
*/
/* helper functions*/
require_once( get_template_directory() . '/framework/helpers.php' );
/* builder functions*/
require_once( get_template_directory() . '/framework/sobuilder.php' );
/* option framework*/
require_once( get_template_directory() . '/framework/admin/admin-init.php' );
/* theme init*/
require_once( get_template_directory() . '/framework/init.php' );
/* create sidebars*/
require_once( get_template_directory() . '/framework/sidebars.php' );
/* create metaboxes*/
require_once( get_template_directory() . '/framework/meta/orion_meta_2.php');
/* site origin specific */
require_once( get_template_directory() . '/widgets/orion_so_filters.php' );

/*
* Tiny MCS specific:
*/
function orion_tinymce_style() {
    add_editor_style( '/framework/css/tiny_mce_styles.css' );
}
add_action( 'admin_init', 'orion_tinymce_style' );

/*
* Admin scripts
*/
function orion_admin_scripts($hook) {
    wp_enqueue_script( 'orion_posts_admin', get_template_directory_uri(). '/framework/js/admin.js' );
    wp_enqueue_style( 'orion_admin-css', get_template_directory_uri(). '/css/admin.css' );
    wp_enqueue_style( 'fontawesome', get_template_directory_uri(). '/libs/font-awesome/css/font-awesome.min.css' ); 
}
add_action( 'admin_enqueue_scripts', 'orion_admin_scripts' );

/*
* Enqueue script for customizer.
*/
function orion_customizer_scripts() {
    wp_enqueue_script( 'orion_admin', get_template_directory_uri(). '/framework/js/admin.js' );
}
add_action( 'customize_preview_init', 'orion_customizer_scripts' );

/*
* Front end scripts
*/
function orion_frontend_scripts($hook) {
    // third-party styles
    wp_enqueue_style( 'bootstrap', get_template_directory_uri(). '/libs/bootstrap/css/bootstrap.css' );	
    wp_enqueue_style('pikaday',  get_template_directory_uri()  .'/libs/pikaday/css/pikaday.css');    
    wp_enqueue_style( 'fontawesome', get_template_directory_uri(). '/libs/font-awesome/css/font-awesome.min.css' ); 
    wp_enqueue_style( 'elegant-icons', get_template_directory_uri(). '/libs/elegant_font/HTMLCSS/style-ot-5.css' ); 
    wp_enqueue_style( 'owl', get_template_directory_uri(). '/libs/owlcarousel/assets/owl.carousel.min.css');
    wp_enqueue_style( 'owl-theme', get_template_directory_uri(). '/libs/owlcarousel/assets/owl.theme.default.min.css');
    wp_enqueue_style( 'swipebox', get_template_directory_uri(). '/libs/swipebox/css/swipebox.min.css' ); 

    // theme style
    wp_enqueue_style( 'dentalia_components', get_template_directory_uri(). '/css/components.css' );
    wp_enqueue_style( 'orion-redux', get_template_directory_uri(). '/framework/css/orion-redux.css', false, rand(1, 99999) );
    if(get_option('dentalia', 'load-css') == 'load-css' ) {
       wp_enqueue_style( 'default-options', get_template_directory_uri(). '/css/default-options.css' ); 
    }    

    
    // third-party scripts
    wp_enqueue_script( 'bootstrap', get_template_directory_uri(). '/libs/bootstrap/js/bootstrap.min.js', array( 'jquery' ) );
    wp_enqueue_script( 'pikaday', get_template_directory_uri()  . '/libs/pikaday/pikaday.js', array('jquery'), '', true );
    wp_enqueue_script( 'smooth-scroll', get_template_directory_uri(). '/libs/smoothscroll/jquery.smooth-scroll.min.js',array('jquery'), '', true );
	wp_enqueue_script( 'owl', get_template_directory_uri(). '/libs/owlcarousel/owl.carousel.min.js', array( 'jquery' ) );
    wp_enqueue_script( 'tab-collapse', get_template_directory_uri(). '/libs/tab-collapse/bootstrap-tabcollapse.js', array( 'jquery', 'bootstrap' ) );
    wp_enqueue_script( 'waypoints', get_template_directory_uri(). '/libs/waypoints/jquery.waypoints.min.js', 'jQuery');
    wp_enqueue_script( 'waypoints-inview', get_template_directory_uri(). '/libs/waypoints/shortcuts/inview.js', 'waypoints');
    wp_enqueue_script( 'waypoints-sticky', get_template_directory_uri(). '/libs/waypoints/shortcuts/sticky.js', 'waypoints'); 
    wp_enqueue_script( 'swipebox', get_template_directory_uri(). '/libs/swipebox/js/jquery.swipebox.min.js', 'jQuery'); 

    // theme scripts
    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }
    wp_enqueue_script( 'dentalia_functions', get_template_directory_uri(). '/js/functions.js', array( 'jquery' ) );
}
add_action( 'wp_enqueue_scripts', 'orion_frontend_scripts' );

/*image sizes */
add_image_size( 'orion_container_width', 1140, 640, true );
add_image_size( 'orion_carousel', 750, 500, true );
add_image_size( 'orion_tablet', 750 );
add_image_size( 'orion_square', 750 , 750, true );

add_filter( 'image_size_names_choose', 'orion_custom_sizes' );
function orion_custom_sizes( $sizes ) {
    return array_merge( $sizes, array(
        'orion_container_width' => __( 'Container width', 'dentalia' ),
        'orion_carousel' => __( '3:2 ratio', 'dentalia' ),
        'orion_tablet' => __( 'Tablet width', 'dentalia' ),
        'orion_square' => __( 'Square', 'dentalia' ),
    ) );
}   

/* add support for excerpt on pages */ 
function orion_page_excerpt() {
    add_post_type_support( 'page', 'excerpt' );
}
add_action( 'init', 'orion_page_excerpt' );

/* revolution remove anoying notices and not used metaboxes */ 
if ( is_admin() ) {
    function orion_remove_revolution_slider_meta_boxes() {
        remove_meta_box( 'mymetabox_revslider_0', 'page', 'normal' );
        remove_meta_box( 'mymetabox_revslider_0', 'post', 'normal' );
        remove_meta_box( 'mymetabox_revslider_0', 'Team', 'normal' );
    }

    add_action( 'do_meta_boxes', 'orion_remove_revolution_slider_meta_boxes' );
}